==> cockpit-ovirt-0.11.29.tar.gz: cockpit-ovirt-0.11.29/dashboard/src/components/HostedEngineSetup/ReviewStep/ReviewStepPanel.js <==
import React, { Component } from 'react'
import ReviewStepContainer from "./ReviewStep";

class ReviewStepPanelContainer extends Component {
    constructor(props) {
        super(props);
        this.state = {
            reviewSteps: this.props.reviewSteps
        }
    }

    render() {
        return (
            <ReviewStepPanel headerText={this.props.headerText}
                             reviewSteps={this.props.reviewSteps.steps} />
        )
    }
}

ReviewStepPanelContainer.propTypes = {
    headerText: React.PropTypes.string,
    reviewSteps: React.PropTypes.object.isRequired
};

const ReviewStepPanel = ({headerText, reviewSteps}) => {
    const steps = [];
    let idx = 0;
    reviewSteps.forEach(
        function(step) {
            steps.push(<ReviewStepContainer stepName={step.stepName}
                                            key={step.stepName + idx++}
                                            reviewItems={step.reviewItems}
                                            isSubStep={false} />);
        }
    );

    return (
        <div className="form-horizontal he-form-container">
            <div className="row">
                <div className="col-md-11 he-wizard-step-header he-wizard-preview-step-header">
                    { headerText }
                </div>
            </div>
            <div className="wizard-pf-review-steps">
                <ul className="list-group">
                    { steps }
                </ul>
            </div>
        </div>
    )
};

export default ReviewStepPanelContainer;

==> cockpit-ovirt-0.12.4.tar.gz: cockpit-ovirt-0.12.4/dashboard/src/components/HostedEngineSetup/ReviewStep/ReviewStepPanel.js <==
import PropTypes from 'prop-types';
import React, { Component } from 'react'
import ReviewStepContainer from "./ReviewStep";

class ReviewStepPanelContainer extends Component {
    constructor(props) {
        super(props);
        this.state = {
            reviewSteps: this.props.reviewSteps
        }
    }

    render() {
        return (
            <ReviewStepPanel headerText={this.props.headerText}
                             reviewSteps={this.props.reviewSteps.steps} />
        )
    }
}

ReviewStepPanelContainer.propTypes = {
    headerText: PropTypes.string,
    reviewSteps: PropTypes.object.isRequired
};

const ReviewStepPanel = ({headerText, reviewSteps}) => {
    const steps = [];
    let idx = 0;
    reviewSteps.forEach(
        function(step) {
            steps.push(<ReviewStepContainer stepName={step.stepName}
                                            key={step.stepName + idx++}
                                            reviewItems={step.reviewItems}
                                            isSubStep={false} />);
        }
    );

    return (
        <div className="form-horizontal he-form-container">
            <div className="row">
                <div className="col-md-11 he-wizard-step-header he-wizard-preview-step-header">
                    { headerText }
                </div>
            </div>
            <div className="wizard-pf-review-steps">
                <ul className="list-group">
                    { steps }
                </ul>
            </div>
        </div>
    )
};

export default ReviewStepPanelContainer;
